@@ -1,4 +1,4 @@
-import circuitpython_esp32connection as connection
+import esp32connection as connection
 
 # Set ssid and password to the SSID and Password of your WiFi
 connection.connect("ssid", "password")
